# Omnissa Horizon Cloud Service Lifecycle Management Plugin SDK

[![PyPI version](https://badge.fury.io/py/ohcs.svg)](https://badge.fury.io/py/ohcs)
[![Python Versions](https://img.shields.io/pypi/pyversions/ohcs.svg)](https://pypi.org/project/ohcs/)
[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Checked with mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](https://mypy-lang.org/)
[![Typed](https://img.shields.io/badge/Typed-Yes-blue.svg)](https://github.com/euc_eng/ohcs)
[![Downloads](https://static.pepy.tech/badge/ohcs)](https://pepy.tech/project/ohcs)

# Getting Started

```shell
pip install -U ohcs
```

https://omnissa.atlassian.net/wiki/spaces/HCS/pages/1118438714/Omnissa+Horizon+Cloud+Lifecycle+Management+Plugin+SDK+-+Developer+Guide
